@@ -14,10 +14,15 @@ import pyntcloud
 
 from pointcloudset.diff import ALL_DIFFS
 from pointcloudset.filter import ALL_FILTERS
-from pointcloudset.io import (POINTCLOUD_FROM_FILE, POINTCLOUD_FROM_INSTANCE,
-                              POINTCLOUD_TO_FILE, POINTCLOUD_TO_INSTANCE)
+from pointcloudset.io import (
+    POINTCLOUD_FROM_FILE,
+    POINTCLOUD_FROM_INSTANCE,
+    POINTCLOUD_TO_FILE,
+    POINTCLOUD_TO_INSTANCE,
+)
 from pointcloudset.plot.pointcloud import plot_overlay
 from pointcloudset.pointcloud_core import PointCloudCore
+from pointcloudset.config import PLOTLYSIZELIMIT
 
 
 class PointCloud(PointCloudCore):
@@ -165,7 +170,12 @@ class PointCloud(PointCloudCore):
 
     def to_instance(
         self, library: Literal["PYNTCLOUD", "OPEN3D", "DATAFRAME", "PANDAS"], **kwargs
-    ) -> Union[pandas.DataFrame, pyntcloud.PyntCloud, open3d.geometry.PointCloud]:
+    ) -> Union[
+        pyntcloud.PyntCloud,
+        open3d.geometry.PointCloud,
+        pandas.DataFrame,
+        pandas.DataFrame,
+    ]:
         """Convert PointCloud to another library instance.
 
         Args:
@@ -205,7 +215,7 @@ class PointCloud(PointCloudCore):
         overlay: dict = {},
         point_size: float = 2,
         prepend_id: str = "",
-        hover_data: List[str] = None,
+        hover_data: Union(List[str], bool) = None,
         **kwargs,
     ) -> plotly.graph_objs.Figure:
         """Plot a PointCloud as a 3D scatter plot with `Plotly <https://plotly.com/>`_.
@@ -226,7 +236,8 @@ class PointCloud(PointCloudCore):
             point_size (float, optional): Size of each point. Defaults to 2.
             prepend_id (str, optional): String before point id to display in hover.
                 Defaults to empty.
-            hover_data (list(str), optional): Data columns to display in hover.
+            hover_data (list(str) or True, optional): Data columns to display in hover. If True
+                then all the columns are are show in the hover.
                 Defaults to None.
             **kwargs: Keyword arguments to pass to func.
 
@@ -240,11 +251,21 @@ class PointCloud(PointCloudCore):
         if color is not None and color not in self.data.columns:
             raise ValueError(f"choose any of {list(self.data.columns)} or None")
 
+        if len(self) > PLOTLYSIZELIMIT:
+            warnings.warn(
+                f"""Pointcloud above limit of {PLOTLYSIZELIMIT}.
+                Plotting might fail or take a long time.
+                Consider donwsampling before plotting.
+                for example: pointcloud.random_down_sample(10000).plot()"""
+            )
+
         ids = [prepend_id + "id=" + str(i) for i in range(self.data.shape[0])]
 
         show_hover = True
         if hover_data is None:
             show_hover = False
+        elif hover_data:
+            hover_data = list(self.data.columns)
         elif isinstance(hover_data, list) & len(hover_data) > 0:
             if self.has_original_id:
                 default = ["original_id"]
@@ -483,3 +504,16 @@ class PointCloud(PointCloudCore):
             return {"PointCloud": inlier_pointcloud, "plane_model": plane_model}
         else:
             return inlier_pointcloud
+
+    def random_down_sample(self, number_of_points: int) -> PointCloud:
+        """Function to downsample input pointcloud into output pointcloud randomly.
+        Made
+
+        Args:
+            number_of_points ([int]): number_of_points
+
+        Returns:
+            PointCloud: subsampled PointCloud
+        """
+        new_data = self.data.sample(number_of_points).reset_index()
+        return PointCloud(new_data, timestamp=self.timestamp)
